@@ -16,13 +16,3 @@ class ExecutionType(Enum):
 
     def value(self) -> str:
         return self.name.lower()
-
-
-def main() -> None:
-    print(ExecutionType.to_enum("buy"))
-    print(ExecutionType.to_enum("sell"))
-    print(ExecutionType.BUY.value())
-
-
-if __name__ == "__main__":
-    main()
